@@ -17,7 +17,6 @@
 #' w1 <- createWorld()
 #' maxPxcor(w1)
 #'
-#'
 #' @export
 #' @rdname maxPxcor
 #'
@@ -27,7 +26,8 @@ setGeneric(
   "maxPxcor",
   function(world) {
     standardGeneric("maxPxcor")
-  })
+  }
+)
 
 #' @export
 #' @rdname maxPxcor
@@ -59,7 +59,6 @@ setMethod(
 #' w1 <- createWorld()
 #' maxPycor(w1)
 #'
-#'
 #' @export
 #' @rdname maxPycor
 #'
@@ -69,7 +68,8 @@ setGeneric(
   "maxPycor",
   function(world) {
     standardGeneric("maxPycor")
-  })
+  }
+)
 
 #' @export
 #' @rdname maxPycor
@@ -101,7 +101,6 @@ setMethod(
 #' w1 <- createWorld()
 #' minPxcor(w1)
 #'
-#'
 #' @export
 #' @rdname minPxcor
 #'
@@ -111,7 +110,8 @@ setGeneric(
   "minPxcor",
   function(world) {
     standardGeneric("minPxcor")
-  })
+  }
+)
 
 #' @export
 #' @rdname minPxcor
@@ -143,7 +143,6 @@ setMethod(
 #' w1 <- createWorld()
 #' minPycor(w1)
 #'
-#'
 #' @export
 #' @rdname minPycor
 #'
@@ -153,7 +152,8 @@ setGeneric(
   "minPycor",
   function(world) {
     standardGeneric("minPycor")
-  })
+  }
+)
 
 #' @export
 #' @rdname minPycor
@@ -185,7 +185,6 @@ setMethod(
 #' w1 <- createWorld()
 #' worldWidth(w1)
 #'
-#'
 #' @export
 #' @rdname worldWidth
 #'
@@ -195,7 +194,8 @@ setGeneric(
   "worldWidth",
   function(world) {
     standardGeneric("worldWidth")
-  })
+  }
+)
 
 #' @export
 #' @rdname worldWidth
@@ -228,7 +228,6 @@ setMethod(
 #' w1 <- createWorld()
 #' worldHeight(w1)
 #'
-#'
 #' @export
 #' @rdname worldHeight
 #'
@@ -238,7 +237,8 @@ setGeneric(
   "worldHeight",
   function(world) {
     standardGeneric("worldHeight")
-  })
+  }
+)
 
 #' @export
 #' @rdname worldHeight
@@ -277,7 +277,6 @@ setMethod(
 #' w1Val <- of(world = w1, agents = patches(w1))
 #' summary(w1Val)
 #'
-#'
 #' @export
 #' @rdname clearPatches
 #'
@@ -308,8 +307,10 @@ setMethod(
   "clearPatches",
   signature = c("worldArray"),
   definition = function(world) {
-    worldNA <- createWorld(minPxcor = minPxcor(world), maxPxcor = maxPxcor(world),
-                                   minPycor = minPycor(world), maxPycor = maxPycor(world))
+    worldNA <- createWorld(
+      minPxcor = minPxcor(world), maxPxcor = maxPxcor(world),
+      minPycor = minPycor(world), maxPycor = maxPycor(world)
+    )
     return(worldNA)
   }
 )
@@ -337,12 +338,13 @@ setMethod(
 #'          will be (pxcor = 0, pycor = 0).
 #'
 #' @examples
-#' r1 <- raster(extent(c(0, 10, 0, 10)), nrows = 10, ncols = 10)
-#' r1[]<-runif(100)
-#' w1 <- raster2world(r1)
-#' plot(r1)
-#' plot(w1)
-#'
+#' if (requireNamespace("raster")) {
+#'   r1 <- raster::raster(raster::extent(c(0, 10, 0, 10)), nrows = 10, ncols = 10)
+#'   r1[] <- runif(100)
+#'   w1 <- raster2world(r1)
+#'   terra::plot(r1)
+#'   terra::plot(w1)
+#' }
 #'
 #' @export
 #' @rdname raster2world
@@ -353,39 +355,121 @@ setGeneric(
   "raster2world",
   function(raster) {
     standardGeneric("raster2world")
-})
+  }
+)
 
 #' @export
 #' @rdname raster2world
 setMethod(
   "raster2world",
-  signature = c("RasterLayer"),
+  signature = c("ANY"),
   definition = function(raster) {
+    if (is(raster, "RasterLayer")) {
+      world <- createWorld(
+        minPxcor = 0, maxPxcor = raster@ncols - 1,
+        minPycor = 0, maxPycor = raster@nrows - 1,
+        data = values(raster)
+      )
+    } else if (is(raster, "RasterStack")) {
+      rasList <- raster::unstack(raster)
+      names(rasList) <- names(raster)
+      worldList <- lapply(rasList, function(ras) {
+        raster2world(ras)
+      })
+      world <- do.call(stackWorlds, worldList)
+    }
+    return(world)
+  }
+)
 
-    world <- createWorld(minPxcor = 0, maxPxcor = raster@ncols - 1,
-                         minPycor = 0, maxPycor = raster@nrows - 1,
-                         data = values(raster))
+
+################################################################################
+#' Convert a `SpatRaster` object into a `worldMatrix` or `worldArray` object
+#'
+#' Convert a `SpatRaster` object into a `worldMatrix`
+#' object or a `worldArray` object depending on the number of layers of the
+#' `SpatRaster` object.
+#'
+#' @param raster `SpatRaster` object.
+#'
+#' @return `WorldMatrix` or `worldArray` object depending on the number of layers
+#' of the input `raster`.
+#'         `Patches` value are retained from the `raster`.
+#'
+#' @details See `help("worldMatrix-class")` or `help("worldArray-class")`
+#'          for more details on the classes.
+#'
+#'          If the `SpatRaster` object has only one layer, a `worldMatrix` object
+#'          will be returned. If the `SpatRaster` object has more than one layer,
+#'          layers must have unique names and a `worldArray` object will be returned.
+#'
+#'          The number of rows and columns, as well as the cell values of the `raster`
+#'          are kept the same. However, to match the coordinates system and resolution of a
+#'          `worldMatrix` or `worldArray`, the grid is shifted by a 1/2 cell to have
+#'          round coordinate values at the center of the patches and patch size is equal to (1,1).
+#'          The bottom left corner cell coordinates of the `worldMatrix` or `worldArray`
+#'          will be (pxcor = 0, pycor = 0).
+#'
+#' @examples
+#' library(terra)
+#' r1 <- rast(xmin = 0, xmax = 10, ymin = 0, ymax = 10, nrows = 10, ncols = 10)
+#' r1[] <- runif(100)
+#' w1 <- spatRast2world(r1)
+#' terra::plot(r1)
+#' plot(w1)
+#'
+#' r2 <- rast(xmin = 0, xmax = 10, ymin = 0, ymax = 10, nrows = 10, ncols = 10)
+#' r2[] <- 0
+#' r3 <- c(r1, r2)
+#' names(r3) <- c("layer1", "layer2")
+#' w3 <- spatRast2world(r3)
+#' terra::plot(r3)
+#' plot(w3)
+#'
+#' @export
+#' @rdname spatRast2world
+#'
+#' @author Sarah Bauduin
+#'
+setGeneric(
+  "spatRast2world",
+  function(raster) {
+    standardGeneric("spatRast2world")
+  }
+)
+
+#' @export
+#' @importFrom terra ncol nrow values
+#' @rdname spatRast2world
+setMethod(
+  "spatRast2world",
+  signature = c("SpatRaster"),
+  definition = function(raster) {
+    if (dim(raster)[3] == 1) { # one layer raster
+      world <- createWorld(
+        minPxcor = 0, maxPxcor = ncol(raster) - 1,
+        minPycor = 0, maxPycor = nrow(raster) - 1,
+        data = values(raster)
+      )
+    } else { # multiple layer raster
+      worldList <- list()
+      for (lay in seq_len(dim(raster)[3])) {
+        worldList[[lay]] <- createWorld(
+          minPxcor = 0, maxPxcor = ncol(raster) - 1,
+          minPycor = 0, maxPycor = nrow(raster) - 1,
+          data = values(raster)[, lay]
+        )
+      }
+      if (any(duplicated(names(raster)))) {
+        stop("Each layer of the SpatRaster must have a unique name")
+      }
+      names(worldList) <- names(raster)
+      world <- do.call(stackWorlds, worldList)
+    }
 
     return(world)
-})
-
-#' @export
-#' @rdname raster2world
-#' @importFrom raster unstack
-setMethod(
-  "raster2world",
-  signature = c("RasterStack"),
-  definition = function(raster) {
-
-    rasList <- raster::unstack(raster)
-    names(rasList) <- names(raster)
-    worldList <- lapply(rasList, function(ras) {
-      raster2world(ras)
-    })
-    wArray <- do.call(stackWorlds, worldList)
-
-    return(wArray)
-})
+  }
+)
 
 ################################################################################
 #' Convert a `worldMatrix` or `worldArray` object into a `Raster*` object
@@ -404,9 +488,10 @@ setMethod(
 #'
 #' @examples
 #' w1 <- createWorld(minPxcor = 0, maxPxcor = 9, minPycor = 0, maxPycor = 9, data = runif(100))
-#' r1 <- world2raster(w1)
-#' plot(r1)
-#'
+#' if (requireNamespace("raster", quietly = TRUE)) {
+#'   r1 <- world2raster(w1)
+#'   terra::plot(r1)
+#' }
 #'
 #' @export
 #' @rdname world2raster
@@ -417,7 +502,8 @@ setGeneric(
   "world2raster",
   function(world) {
     standardGeneric("world2raster")
-  })
+  }
+)
 
 
 #' @export
@@ -426,11 +512,16 @@ setMethod(
   "world2raster",
   signature = c("worldMatrix"),
   definition = function(world) {
-    ras <- raster(world@.Data, xmn = world@extent@xmin, xmx = world@extent@xmax,
-                     ymn = world@extent@ymin, ymx = world@extent@ymax)
+    exts <- extents(world@extent)
+    if (!requireNamespace("raster", quietly = TRUE)) stop("Need to install.packages('raster')")
+    ras <- raster::raster(world@.Data,
+      xmn = exts$xmin, xmx = exts$xmax,
+      ymn = exts$ymin, ymx = exts$ymax
+    )
 
     return(ras)
-  })
+  }
+)
 
 
 #' @export
@@ -439,15 +530,100 @@ setMethod(
   "world2raster",
   signature = c("worldArray"),
   definition = function(world) {
-
-    listRaster <- lapply(1:dim(world)[3], function(x) {
-      raster(world@.Data[, , x], xmn = world@extent@xmin, xmx = world@extent@xmax,
-             ymn = world@extent@ymin, ymx = world@extent@ymax)
+    if (!requireNamespace("raster", quietly = TRUE)) {
+      stop("Need to install.packages('raster')")
+    }
+    exts <- extents(world@extent)
+    listRaster <- lapply(seq_len(dim(world)[3]), function(x) {
+      raster::raster(world@.Data[, , x],
+        xmn = exts$xmin, xmx = exts$xmax,
+        ymn = exts$ymin, ymx = exts$ymax
+      )
     })
-    rasterStack <- stack(listRaster)
+    rasterStack <- raster::stack(listRaster)
     return(rasterStack)
-})
+  }
+)
 
+################################################################################
+#' Convert a `worldMatrix` or `worldArray` object into a `SpatRaster` object
+#'
+#' Convert a `worldMatrix` object or a
+#' `worldArray` object into a `SpatRaster` object
+#'
+#' @inheritParams fargs
+#'
+#' @return `SpatRaster` object.
+#'         `Patches` value are retained from the `world`.
+#'
+#' @details The `SpatRaster` returned has the same extent and resolution as the `world`
+#'          with round coordinates at the center of the cells and coordinates `x.5`
+#'          at the edges of the cells.
+#'
+#' @examples
+#' w1 <- createWorld(minPxcor = 0, maxPxcor = 9, minPycor = 0, maxPycor = 9, data = runif(100))
+#' r1 <- world2spatRast(w1)
+#' terra::plot(r1)
+#'
+#' w2 <- createWorld(minPxcor = 0, maxPxcor = 9, minPycor = 0, maxPycor = 9, data = 0)
+#' w3 <- stackWorlds(w1, w2)
+#' r3 <- world2spatRast(w3)
+#' terra::plot(r3)
+#'
+#' @export
+#' @importFrom terra rast
+#' @rdname world2spatRast
+#'
+#' @author Sarah Bauduin
+#'
+setGeneric(
+  "world2spatRast",
+  function(world) {
+    standardGeneric("world2spatRast")
+  }
+)
+
+
+#' @export
+#' @rdname world2spatRast
+setMethod(
+  "world2spatRast",
+  signature = c("worldMatrix"),
+  definition = function(world) {
+    exts <- extents(world@extent)
+    ras <- rast(
+      xmin = exts$xmin, xmax = exts$xmax,
+      ymin = exts$ymin, ymax = exts$ymax,
+      ncol = ncol(world), nrow = nrow(world)
+    )
+    terra::values(ras) <- world@.Data
+
+    return(ras)
+  }
+)
+
+
+#' @export
+#' @rdname world2spatRast
+setMethod(
+  "world2spatRast",
+  signature = c("worldArray"),
+  definition = function(world) {
+    exts <- extents(world@extent)
+    listRaster <- lapply(seq_len(dim(world)[3]), function(x) {
+      ras <- terra::rast(
+        xmin = exts$xmin, xmax = exts$xmax,
+        ymin = exts$ymin, ymax = exts$ymax,
+        ncol = ncol(world), nrow = nrow(world), vals = world@.Data[, , x]
+      )
+    })
+    rasterStack <- rast(listRaster)
+    names(rasterStack) <- colnames(world[, , ])
+    return(rasterStack)
+  }
+)
+
+################################################################################
 #' Key base R functions for `worldNLR` classes
 #'
 #' Slight modifications from the default versions.
@@ -457,60 +633,68 @@ setMethod(
 #' @export
 #' @importFrom quickPlot numLayers
 #' @rdname show-methods
+#' @return `show` is called for its side effects. It shows key metadata elements
+#' of the `worldArray` or `worldMatrix`, plus the first 4 columns and rows of data
 setMethod(
   "show",
   signature(object = "worldArray"),
   definition = function(object) {
     cat("class       :", class(object), "\n")
     cat("resolution  :", paste(object@res, collapse = ", "), "(x, y)\n")
-    cat("dimensions  : Pxcor: ", object@minPxcor, ",", object@maxPxcor, "\n",
-        "             Pycor: ", object@minPycor, ",", object@maxPycor, "\n")
+    cat(
+      "dimensions  : Pxcor: ", object@minPxcor, ",", object@maxPxcor, "\n",
+      "             Pycor: ", object@minPycor, ",", object@maxPycor, "\n"
+    )
 
     # Copied and modified from show method in Raster
-      minv <- format(apply(object@.Data, 3, min))
-      maxv <- format(apply(object@.Data, 3, max))
-      minv <- gsub("Inf", "?", minv)
-      maxv <- gsub("-Inf", "?", maxv)
-      nl <- numLayers(object)
-      mnr <- 15
+    minv <- format(apply(object@.Data, 3, min))
+    maxv <- format(apply(object@.Data, 3, max))
+    minv <- gsub("Inf", "?", minv)
+    maxv <- gsub("-Inf", "?", maxv)
+    nl <- numLayers(object)
+    mnr <- 15
 
-      if (nl > mnr) {
-        minv <- c(minv[1:mnr], "...")
-        maxv <- c(maxv[1:mnr], "...")
-      }
+    if (nl > mnr) {
+      minv <- c(minv[1:mnr], "...")
+      maxv <- c(maxv[1:mnr], "...")
+    }
 
-      ln <- dimnames(object)[[3]]
-      n <- nchar(ln)
-      if (nl > 5) {
-        b <- n > 26
-        if (any(b)) {
-          mid <- floor(n/2)
-          ln[b] <- paste(substr(ln[b], 1, 9), "//",
-                         substr(ln[b], nchar(ln[b]) - 9, nchar(ln[b])), sep = "")
-        }
+    ln <- dimnames(object)[[3]]
+    n <- nchar(ln)
+    if (nl > 5) {
+      b <- n > 26
+      if (any(b)) {
+        mid <- floor(n / 2)
+        ln[b] <- paste(substr(ln[b], 1, 9), "//",
+          substr(ln[b], nchar(ln[b]) - 9, nchar(ln[b])),
+          sep = ""
+        )
       }
+    }
 
-      w <- pmax(nchar(ln), nchar(minv), nchar(maxv))
-      m <- rbind(ln, minv, maxv)
-      # a loop because 'width' is not recycled by format
-      for (i in 1:ncol(m)) {
-        m[, i]   <- format(m[, i], width = w[i], justify = "right")
-      }
-      cat("names       :", paste(m[1, ], collapse = ", "), "\n")
-      cat("min values  :", paste(m[2, ], collapse = ", "), "\n")
-      cat("max values  :", paste(m[3, ], collapse = ", "), "\n")
+    w <- pmax(nchar(ln), nchar(minv), nchar(maxv))
+    m <- rbind(ln, minv, maxv)
+    # a loop because 'width' is not recycled by format
+    for (i in seq_len(ncol(m))) {
+      m[, i] <- format(m[, i], width = w[i], justify = "right")
+    }
+    cat("names       :", paste(m[1, ], collapse = ", "), "\n")
+    cat("min values  :", paste(m[2, ], collapse = ", "), "\n")
+    cat("max values  :", paste(m[3, ], collapse = ", "), "\n")
 
     # } else {
     #   cat("names       :", paste(ln, collapse=", "), "\n")
     # }
-      dims <- dim(object@.Data)
-      dims <- pmin(dims, 4)
-      if (any(dims >= 4))
-        cat("First",dims[1],"rows and ",dims[2],"columns:\n")
+    dims <- dim(object@.Data)
+    dims <- pmin(dims, 4)
+    if (any(dims >= 4)) {
+      cat("First", dims[1], "rows and ", dims[2], "columns:\n")
+    }
 
     # cat("First 4 rows and columns:\n")
-      print(object@.Data[1:dims[1], 1:dims[2], ])
-})
+    print(object@.Data[1:dims[1], 1:dims[2], ])
+  }
+)
 
 #' @export
 #' @rdname show-methods
@@ -520,8 +704,10 @@ setMethod(
   definition = function(object) {
     cat("class       :", class(object), "\n")
     cat("resolution  :", paste(object@res, collapse = ", "), "(x, y)\n")
-    cat("dimensions  : Pxcor: ", object@minPxcor, ",", object@maxPxcor, "\n",
-        "             Pycor: ", object@minPycor, ",", object@maxPycor, "\n")
+    cat(
+      "dimensions  : Pxcor: ", object@minPxcor, ",", object@maxPxcor, "\n",
+      "             Pycor: ", object@minPycor, ",", object@maxPycor, "\n"
+    )
 
     # Copied and modified from show method in Raster
     minv <- format(min(object@.Data))
@@ -533,14 +719,16 @@ setMethod(
     w <- pmax(nchar(ln), nchar(minv), nchar(maxv))
     m <- rbind(ln, minv, maxv)
     # a loop because 'width' is not recycled by format
-    m   <- format(m, width = w, justify = "right")
+    m <- format(m, width = w, justify = "right")
     cat("names       :", paste(m[1, ], collapse = ", "), "\n")
     cat("min values  :", paste(m[2, ], collapse = ", "), "\n")
     cat("max values  :", paste(m[3, ], collapse = ", "), "\n")
 
     dims <- dim(object@.Data)
     dims <- pmin(dims, 4)
-    if (any(dims >= 4))
-      cat("First",dims[1],"rows and ",dims[2],"columns:\n")
+    if (any(dims >= 4)) {
+      cat("First", dims[1], "rows and ", dims[2], "columns:\n")
+    }
     print(object@.Data[1:dims[1], 1:dims[2]])
-})
+  }
+)
